Summary:       A key/value pair database to store software configurations
Name:          elektra
Version:       0.7.0
Release:       %mkrel 2
Group:         System/Libraries
License:       BSD
URL:           http://www.libelektra.org
Source0:       http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.xz
Patch0:        elektra-0.7.0-rename.patch
Patch1:        elektra-0.7.0-no_local.patch
BuildRoot:     %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: doxygen db4-devel libxml2-devel docbook-style-xsl %{_lib}xslt1
BuildRequires: gawk
BuildRequires: GConf2-devel
BuildRequires: libtool, gettext-devel
Requires(post): /sbin/ldconfig


%description
Elektra provides a universal and secure framework to store configuration
parameters in a hierarchical key-value pair mechanism, instead of each
program using its own text configuration files. This allows any program
to read and save its configuration with a consistent API, and allows
them to be aware of other applications' configurations, permitting
easy application integration. While architecturally similar to other OS
registries, Elektra does not have most of the problems found in those
implementations.

This package also contains a Berkeley DB backend for Elektra, to let 
Elektra use Berkeley DB databases to store its keys and daemon which can
be used as a proxy for access to the keys.


%package devel
Summary:      Include files and API documentation to build elektrified programs
Group:        Development/Libraries
Requires:     pkgconfig 
Requires:     %{name} = %{version}-%{release}

%description devel
Elektra provides a universal and secure framework to store configuration
parameters in a hierarchical key-value pair tree.

This package contains development specific things as include files to 
create elektrified programs.



%prep
%setup -q
%patch0 -p1 -b .rename
%patch1 -p1 -b .local



%build
export CFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE"
export CXXFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE"
./configure --prefix=/usr \
     --includedir=%{_includedir}/elektra \
     --program-prefix=%{name}- \
     --disable-static \
     --disable-rpath \
     --with-ulibdir=%{_libdir} \
     --with-docbook=%{_datadir}/sgml/docbook/xsl-stylesheets \
     --with-kdbschemadir=%{_datadir}/sgml/%{name}-%{version} \
     --enable-iconv

# remove rpath from libtool
sed -i.rpath 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i.rpath 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool


make


%install
rm -rf $RPM_BUILD_ROOT

make DESTDIR=$RPM_BUILD_ROOT install INSTALL='install -p'

find %{buildroot} -name '*.la' -exec rm -f {} \;
find %{buildroot} -name '*.a' -exec rm -f {} \;


find $RPM_BUILD_ROOT%{_libdir} -type f -a -name \*.la -exec rm {} \;

# Remove statically linked kdb - lib
rm $RPM_BUILD_ROOT%{_bindir}/*_static

## doc fixes
rm -rf __doc __doc-devel
mkdir __doc
mv  $RPM_BUILD_ROOT%{_datadir}/doc/elektra/* __doc
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/elektra
mkdir __doc-devel
mv  $RPM_BUILD_ROOT%{_datadir}/doc/elektra-devel/* __doc-devel
touch -r ChangeLog __doc-devel/api-html/*
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc/elektra-devel


## man fixes (from program prefix)
mv $RPM_BUILD_ROOT%{_mandir}/man5/elektra-elektra.5 $RPM_BUILD_ROOT%{_mandir}/man5/elektra.5
mv $RPM_BUILD_ROOT%{_mandir}/man7/elektra-elektra.7 $RPM_BUILD_ROOT%{_mandir}/man7/elektra.7

mkdir -p $RPM_BUILD_ROOT/etc/profile.d
mv $RPM_BUILD_ROOT/usr/etc/profile.d/elektra-elektraenv.sh $RPM_BUILD_ROOT/etc/profile.d/elektra-elektraenv.sh

# The init-script is disabled for now
rm -rf $RPM_BUILD_ROOT/usr/etc/init.d/elektra-kdbd
#Own the directory where configuration will be stored.
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/kdb


%clean
rm -rf $RPM_BUILD_ROOT


%post
/sbin/ldconfig
# Create basic key structure for apps
elektra-kdb set -t dir system/sw > /dev/null 2>&1
elektra-kdb set system/sw/kdb/schemapath "%{_datadir}/sgml/elektra-%{version}/elektra.xsd" > /dev/null 2>&1 || :

%postun
/sbin/ldconfig


%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING ChangeLog README INSTALL
%doc __doc/*
%dir %{_sysconfdir}/kdb
%{_bindir}/elektra-kdb
%{_bindir}/elektra-preload
/usr/lib/elektra
/usr/lib/libelektra*.so.*
%{_mandir}/man1/*
%{_mandir}/man7/*
%{_mandir}/man5/*
%{_datadir}/sgml/elektra-%{version}/
/etc/profile.d/elektra-elektraenv.sh
%{_libdir}/libelektratools.so.2
%{_libdir}/libelektratools.so.2.0.0


%files devel
%defattr(-,root,root,-)
%doc __doc-devel/*
%{_includedir}/elektra/
/usr/lib/libelektra.so
/usr/lib/libelektra-cpp.so
%{_libdir}/libelektratools.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*



%changelog
* Sat Jul 16 2016 adrianomorselli <adrianomorselli> 0.7.0-2uplos2013
- rebuild
* Mon Apr 15 2013 Texstar <texstar at gmail.com> 0.7.0-2pclos2013
- rebuild for 64bit
- this is an old file and a mess

* Thu Jun 10 2010 pcserver <pcserver at inbox.com> 0.7.0-1pclos2010
- create